==> iot-1.182.0-sources.jar: software/amazon/awscdk/services/iot/CfnResourceSpecificLoggingProps.java <==
package software.amazon.awscdk.services.iot;

/**
 * Properties for defining a `CfnResourceSpecificLogging`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.iot.*;
 * CfnResourceSpecificLoggingProps cfnResourceSpecificLoggingProps = CfnResourceSpecificLoggingProps.builder()
 *         .logLevel("logLevel")
 *         .targetName("targetName")
 *         .targetType("targetType")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:36.052Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.iot.$Module.class, fqn = "@aws-cdk/aws-iot.CfnResourceSpecificLoggingProps")
@software.amazon.jsii.Jsii.Proxy(CfnResourceSpecificLoggingProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnResourceSpecificLoggingProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The default log level.Valid Values: `DEBUG | INFO | ERROR | WARN | DISABLED`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getLogLevel();

    /**
     * The target name.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getTargetName();

    /**
     * The target type.
     * <p>
     * Valid Values: <code>DEFAULT | THING_GROUP</code>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getTargetType();

    /**
     * @return a {@link Builder} of {@link CfnResourceSpecificLoggingProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnResourceSpecificLoggingProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnResourceSpecificLoggingProps> {
        java.lang.String logLevel;
        java.lang.String targetName;
        java.lang.String targetType;

        /**
         * Sets the value of {@link CfnResourceSpecificLoggingProps#getLogLevel}
         * @param logLevel The default log level.Valid Values: `DEBUG | INFO | ERROR | WARN | DISABLED`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder logLevel(java.lang.String logLevel) {
            this.logLevel = logLevel;
            return this;
        }

        /**
         * Sets the value of {@link CfnResourceSpecificLoggingProps#getTargetName}
         * @param targetName The target name. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder targetName(java.lang.String targetName) {
            this.targetName = targetName;
            return this;
        }

        /**
         * Sets the value of {@link CfnResourceSpecificLoggingProps#getTargetType}
         * @param targetType The target type. This parameter is required.
         *                   Valid Values: <code>DEFAULT | THING_GROUP</code>
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder targetType(java.lang.String targetType) {
            this.targetType = targetType;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnResourceSpecificLoggingProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnResourceSpecificLoggingProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnResourceSpecificLoggingProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnResourceSpecificLoggingProps {
        private final java.lang.String logLevel;
        private final java.lang.String targetName;
        private final java.lang.String targetType;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.logLevel = software.amazon.jsii.Kernel.get(this, "logLevel", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.targetName = software.amazon.jsii.Kernel.get(this, "targetName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.targetType = software.amazon.jsii.Kernel.get(this, "targetType", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.logLevel = java.util.Objects.requireNonNull(builder.logLevel, "logLevel is required");
            this.targetName = java.util.Objects.requireNonNull(builder.targetName, "targetName is required");
            this.targetType = java.util.Objects.requireNonNull(builder.targetType, "targetType is required");
        }

        @Override
        public final java.lang.String getLogLevel() {
            return this.logLevel;
        }

        @Override
        public final java.lang.String getTargetName() {
            return this.targetName;
        }

        @Override
        public final java.lang.String getTargetType() {
            return this.targetType;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("logLevel", om.valueToTree(this.getLogLevel()));
            data.set("targetName", om.valueToTree(this.getTargetName()));
            data.set("targetType", om.valueToTree(this.getTargetType()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-iot.CfnResourceSpecificLoggingProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnResourceSpecificLoggingProps.Jsii$Proxy that = (CfnResourceSpecificLoggingProps.Jsii$Proxy) o;

            if (!logLevel.equals(that.logLevel)) return false;
            if (!targetName.equals(that.targetName)) return false;
            return this.targetType.equals(that.targetType);
        }

        @Override
        public final int hashCode() {
            int result = this.logLevel.hashCode();
            result = 31 * result + (this.targetName.hashCode());
            result = 31 * result + (this.targetType.hashCode());
            return result;
        }
    }
}

==> iot-1.204.0-sources.jar: software/amazon/awscdk/services/iot/CfnResourceSpecificLoggingProps.java <==
package software.amazon.awscdk.services.iot;

/**
 * Properties for defining a <code>CfnResourceSpecificLogging</code>.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.iot.*;
 * CfnResourceSpecificLoggingProps cfnResourceSpecificLoggingProps = CfnResourceSpecificLoggingProps.builder()
 *         .logLevel("logLevel")
 *         .targetName("targetName")
 *         .targetType("targetType")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.84.0 (build 5404dcf)", date = "2023-06-19T16:29:57.594Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.iot.$Module.class, fqn = "@aws-cdk/aws-iot.CfnResourceSpecificLoggingProps")
@software.amazon.jsii.Jsii.Proxy(CfnResourceSpecificLoggingProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnResourceSpecificLoggingProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The default log level.Valid Values: <code>DEBUG | INFO | ERROR | WARN | DISABLED</code>.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getLogLevel();

    /**
     * The target name.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getTargetName();

    /**
     * The target type.
     * <p>
     * Valid Values: <code>DEFAULT | THING_GROUP</code>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getTargetType();

    /**
     * @return a {@link Builder} of {@link CfnResourceSpecificLoggingProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnResourceSpecificLoggingProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnResourceSpecificLoggingProps> {
        java.lang.String logLevel;
        java.lang.String targetName;
        java.lang.String targetType;

        /**
         * Sets the value of {@link CfnResourceSpecificLoggingProps#getLogLevel}
         * @param logLevel The default log level.Valid Values: <code>DEBUG | INFO | ERROR | WARN | DISABLED</code>. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder logLevel(java.lang.String logLevel) {
            this.logLevel = logLevel;
            return this;
        }

        /**
         * Sets the value of {@link CfnResourceSpecificLoggingProps#getTargetName}
         * @param targetName The target name. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder targetName(java.lang.String targetName) {
            this.targetName = targetName;
            return this;
        }

        /**
         * Sets the value of {@link CfnResourceSpecificLoggingProps#getTargetType}
         * @param targetType The target type. This parameter is required.
         *                   Valid Values: <code>DEFAULT | THING_GROUP</code>
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder targetType(java.lang.String targetType) {
            this.targetType = targetType;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnResourceSpecificLoggingProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnResourceSpecificLoggingProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnResourceSpecificLoggingProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnResourceSpecificLoggingProps {
        private final java.lang.String logLevel;
        private final java.lang.String targetName;
        private final java.lang.String targetType;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.logLevel = software.amazon.jsii.Kernel.get(this, "logLevel", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.targetName = software.amazon.jsii.Kernel.get(this, "targetName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.targetType = software.amazon.jsii.Kernel.get(this, "targetType", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.logLevel = java.util.Objects.requireNonNull(builder.logLevel, "logLevel is required");
            this.targetName = java.util.Objects.requireNonNull(builder.targetName, "targetName is required");
            this.targetType = java.util.Objects.requireNonNull(builder.targetType, "targetType is required");
        }

        @Override
        public final java.lang.String getLogLevel() {
            return this.logLevel;
        }

        @Override
        public final java.lang.String getTargetName() {
            return this.targetName;
        }

        @Override
        public final java.lang.String getTargetType() {
            return this.targetType;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("logLevel", om.valueToTree(this.getLogLevel()));
            data.set("targetName", om.valueToTree(this.getTargetName()));
            data.set("targetType", om.valueToTree(this.getTargetType()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-iot.CfnResourceSpecificLoggingProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnResourceSpecificLoggingProps.Jsii$Proxy that = (CfnResourceSpecificLoggingProps.Jsii$Proxy) o;

            if (!logLevel.equals(that.logLevel)) return false;
            if (!targetName.equals(that.targetName)) return false;
            return this.targetType.equals(that.targetType);
        }

        @Override
        public final int hashCode() {
            int result = this.logLevel.hashCode();
            result = 31 * result + (this.targetName.hashCode());
            result = 31 * result + (this.targetType.hashCode());
            return result;
        }
    }
}
